smcp
====

Solver for sparse matrix cone programs

Documentation available at http://smcp.rtfd.org

[![Build Status](https://travis-ci.org/cvxopt/smcp.svg?branch=master)](https://travis-ci.org/cvxopt/smcp)
[![Documentation Status](https://readthedocs.org/projects/smcp/badge/?version=latest)](http://smcp.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/badge/license-GPL3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
